Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/bluefruitconnect_simpletest.py
    :caption: examples/bluefruitconnect_simpletest.py
    :linenos:

This test demonstrates controlling an Adafruit Crickit board with Bluetooth.

.. literalinclude:: ../examples/bluefruitconnect_accelerometer_packet_test.py
    :caption: examples/bluefruitconnect_accelerometer_packet_test.py
    :linenos:
